AuthTokenData class

Constructors

AuthTokenData({required String accessToken, required String refreshToken, required int issuedAt, required int expiresAt, String? platform})

Properties

accessToken String
final
expiredAtDateTime DateTime
no setter
expiresAt int
final
hashCode int
The hash code for this object.
no setterinherited
issuedAt int
final
issuedAtDateTime DateTime
no setter
platform String?
final
refreshToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited