AuthenticationGuard class

Constructors

AuthenticationGuard(BuildContext context, {required PageRouteInfo authRoute, required PageRouteInfo initialScreenRoute, required PageRouteInfo errorRoute(Object? error), bool removeRoutesPredicateOnAuth(StackRouter router)?})

Properties

authRoute → PageRouteInfo
final
context BuildContext
final
errorRoute → PageRouteInfo Function(Object? error)
final
hashCode int
The hash code for this object.
no setterinherited
initialScreenRoute → PageRouteInfo
final
removeRoutesPredicateOnAuth bool Function(StackRouter router)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onNavigation(NavigationResolver resolver, StackRouter router) Future<void>
clients will call resolver.next(true --> default) to continue navigation or resolver.next(false) to abort navigation example
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited