AuthenticationRepository class abstract

Constructors

AuthenticationRepository({String? platform})

Properties

authExceptionsStream Stream<AuthException>
no setter
hashCode int
The hash code for this object.
no setterinherited
platform String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAuthToken() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAuthentication(AuthenticatedResponse authenticatedResponse) → void
onLogOut() → void
requestOTP(RequestOTPRequest request) Future<RequestOTPResponse>
toString() String
A string representation of this object.
inherited
updateAuthToken(String refreshToken) Future<AuthTokenData>
verifyOTP(OTPVerificationRequest request) Future<AuthenticatedResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited