LogOut class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
onComplete
→ VoidCallback?
-
Callback to execute whenever the event finished its tasks.
finalinherited
-
onError
→ void Function(Object? e)?
-
Callback to execute if the event encounters an error.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited