OTPVerificationRequest class

Constructors

OTPVerificationRequest({required ContactNumber contactNumber, required String otp})

Properties

contactNumber ContactNumber
final
hashCode int
The hash code for this object.
no setterinherited
otp String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited